@@ -37,6 +37,11 @@
 typedef struct _PangoFT2Family       PangoFT2Family;
 typedef struct _PangoFT2FontMapClass PangoFT2FontMapClass;
 
+/**
+ * PangoFT2FontMap:
+ *
+ * The #PangoFT2FontMap is the #PangoFontMap implementation for FreeType fonts.
+ */
 struct _PangoFT2FontMap
 {
   PangoFcFontMap parent_instance;
@@ -68,6 +73,7 @@ static PangoFcFont * pango_ft2_font_map_new_font            (PangoFcFontMap
 static double        pango_ft2_font_map_get_resolution      (PangoFcFontMap       *fcfontmap,
 							     PangoContext         *context);
 static guint         pango_ft2_font_map_get_serial          (PangoFontMap         *fontmap);
+static void          pango_ft2_font_map_changed             (PangoFontMap         *fontmap);
 
 static PangoFT2FontMap *pango_ft2_global_fontmap = NULL; /* MT-safe */
 
@@ -82,6 +88,7 @@ pango_ft2_font_map_class_init (PangoFT2FontMapClass *class)
 
   gobject_class->finalize = pango_ft2_font_map_finalize;
   fontmap_class->get_serial = pango_ft2_font_map_get_serial;
+  fontmap_class->changed = pango_ft2_font_map_changed;
   fcfontmap_class->default_substitute = _pango_ft2_font_map_default_substitute;
   fcfontmap_class->new_font = pango_ft2_font_map_new_font;
   fcfontmap_class->get_resolution = pango_ft2_font_map_get_resolution;
@@ -132,8 +139,10 @@ pango_ft2_font_map_new (void)
   PangoFT2FontMap *ft2fontmap;
   FT_Error error;
 
+#if !GLIB_CHECK_VERSION (2, 35, 3)
   /* Make sure that the type system is initialized */
   g_type_init ();
+#endif
 
   ft2fontmap = g_object_new (PANGO_TYPE_FT2_FONT_MAP, NULL);
 
@@ -152,6 +161,16 @@ pango_ft2_font_map_get_serial (PangoFontMap *fontmap)
   return ft2fontmap->serial;
 }
 
+static void
+pango_ft2_font_map_changed (PangoFontMap *fontmap)
+{
+  PangoFT2FontMap *ft2fontmap = PANGO_FT2_FONT_MAP (fontmap);
+
+  ft2fontmap->serial++;
+  if (ft2fontmap->serial == 0)
+    ft2fontmap->serial++;
+}
+
 /**
  * pango_ft2_font_map_set_default_substitute:
  * @fontmap: a #PangoFT2FontMap
@@ -189,7 +208,7 @@ pango_ft2_font_map_set_default_substitute (PangoFT2FontMap        *fontmap,
 
 /**
  * pango_ft2_font_map_substitute_changed:
- * @fontmap: a #PangoFT2Fontmap
+ * @fontmap: a #PangoFT2FontMap
  *
  * Call this function any time the results of the
  * default substitution function set with
@@ -210,7 +229,7 @@ pango_ft2_font_map_substitute_changed (PangoFT2FontMap *fontmap)
 
 /**
  * pango_ft2_font_map_set_resolution:
- * @fontmap: a #PangoFT2Fontmap
+ * @fontmap: a #PangoFT2FontMap
  * @dpi_x: dots per inch in the X direction
  * @dpi_y: dots per inch in the Y direction
  *
@@ -232,8 +251,8 @@ pango_ft2_font_map_set_resolution (PangoFT2FontMap *fontmap,
 }
 
 /**
- * pango_ft2_font_map_create_context:
- * @fontmap: a #PangoFT2Fontmap
+ * pango_ft2_font_map_create_context: (skip)
+ * @fontmap: a #PangoFT2FontMap
  *
  * Create a #PangoContext for the given fontmap.
  *
@@ -252,18 +271,19 @@ pango_ft2_font_map_create_context (PangoFT2FontMap *fontmap)
 }
 
 /**
- * pango_ft2_get_context:
+ * pango_ft2_get_context: (skip)
  * @dpi_x:  the horizontal DPI of the target device
  * @dpi_y:  the vertical DPI of the target device
  *
  * Retrieves a #PangoContext for the default PangoFT2 fontmap
- * (see pango_ft2_fontmap_get_for_display()) and sets the resolution
+ * (see pango_ft2_font_map_for_display()) and sets the resolution
  * for the default fontmap to @dpi_x by @dpi_y.
  *
  * Return value: the new #PangoContext
  *
  * Deprecated: 1.22: Use pango_font_map_create_context() instead.
  **/
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 PangoContext *
 pango_ft2_get_context (double dpi_x, double dpi_y)
 {
@@ -274,9 +294,10 @@ pango_ft2_get_context (double dpi_x, double dpi_y)
 
   return pango_font_map_create_context (fontmap);
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
- * pango_ft2_font_map_for_display:
+ * pango_ft2_font_map_for_display: (skip)
  *
  * Returns a #PangoFT2FontMap. This font map is cached and should
  * not be freed. If the font map is no longer needed, it can
@@ -289,8 +310,8 @@ pango_ft2_get_context (double dpi_x, double dpi_y)
 PangoFontMap *
 pango_ft2_font_map_for_display (void)
 {
-  if (g_once_init_enter ((gsize*)&pango_ft2_global_fontmap))
-    g_once_init_leave((gsize*)&pango_ft2_global_fontmap, (gsize)pango_ft2_font_map_new ());
+  if (g_once_init_enter (&pango_ft2_global_fontmap))
+    g_once_init_leave(&pango_ft2_global_fontmap, PANGO_FT2_FONT_MAP (pango_ft2_font_map_new ()));
 
   return PANGO_FONT_MAP (pango_ft2_global_fontmap);
 }
@@ -325,7 +346,7 @@ _pango_ft2_font_map_get_library (PangoFontMap *fontmap)
 
 /**
  * _pango_ft2_font_map_get_renderer:
- * @fontmap: a #PangoFT2Fontmap
+ * @fontmap: a #PangoFT2FontMap
  *
  * Gets the singleton PangoFT2Renderer for this fontmap.
  *
